at_persistence_secondary_server library

Classes

AccessLogKeyStore
AtAccessLog
Class to main access logs on the secondary server for from, cram, pol, lookup and plookup verbs
AtAccessLogManager
Factory class. Responsible for returning instance of a AtCommitLog.
AtAccessLogManagerImpl
AtClientAnnotation
Class for at_client annotation. Methods that are used by at_client/at_client_mobile are marked with this annotation.
AtCommitLog
Class to maintain commit logs on the secondary server for create, update and remove operations on keys
AtCommitLogManager
Factory class. Responsible for returning instance of a AtCommitLog.
AtCommitLogManagerImpl
AtCompaction<K, V>
AtCompaction deletes keys from the Keystore to reduce the size of the KeyStore.
AtCompactionConfig
The configurations for the AtCompaction Job.
AtCompactionConstants
AtCompactionJob
The class responsible for the triggering the compaction job.
AtCompactionService
The AtCompactionService is runs on the Keystore and removes the oldest keys to reduce the size of the Keystore.
AtCompactionStats
Type to collect and store compaction statistics
AtCompactionStatsService
The AtCompactionStatsService collects compaction metrics and writes them to SecondaryKeyStore
AtCompactionStatsServiceImpl
An implementation class of AtCompactionStatsService to write the compaction metrics to the SecondaryKeyStore
AtCompactionStrategy
The abstract class for Compaction Job
AtConfig
Class to configure blocklist for atConnections.
AtData
AtDataAdapter
AtLogType<K, V>
The base class for Log.
AtMetaData
AtMetaDataAdapter
AtMetadataBuilder
Builder class to build AtMetaData object.
AtNotification
Represents an AtNotification entry in keystore.
AtNotificationAdapter
Class for registering AtNotification to the hive type adapter.
AtNotificationBuilder
AtNotificationBuilder class to build AtNotification object
AtNotificationCallback
Class for AtNotification callback method implementations
AtNotificationKeystore
Class to initialize, put and get entries into AtNotificationKeystore
AtServerAnnotation
Class for at_server custom annotation. Methods that are used by at_secondary_server are marked with this annotation.
BaseAtCommitLog
BaseCommitLogKeyStore
ClientAtCommitLog
ClientCommitLogKeyStore
CommitEntry
Represents a commit entry with a key, CommitOperation and a commit id
CommitEntryAdapter
Hive type adapter for CommitEntry
CommitLogCache
CommitLogCompactionService
CommitLogCompactionService class is responsible for compacting the AtCommitLog Listens on the AtChangeEventListener and increments keysToCompactCount on each insert into the commit-log. When keysToCompactCount reaches threshold (50), compaction triggers and removes the duplicate CommitEntry
CommitLogKeyStore
CommitOpAdapter
HivePersistenceManager
Keystore<K, V>
Keystore represents a data store like a database which can store mapping between keys and values.
KeystoreManager<K, V>
Factory class. Responsible for returning instance of a Key store.
LogKeyStore<K, V>
Keystore represents a data store like a database which can store mapping between keys and values.
MessageTypeAdapter
NotificationFunction
NotificationManagerSpec
Class to represent to the NotificationManager Spec.
NotificationPriorityAdapter
class for representing NotificationStatus enum to the hive type adapter
NotificationStatusAdapter
class for representing NotificationStatus enum to the hive type adapter
NotificationStrategy
NotificationTypeAdapter
class for representing NotificationType enum to the hive type adapter
NullCommitEntry
Represents a CommitEntry with all instances pointing to null/defaults.
OperationTypeAdapter
class for representing OperationType enum to the hive type adapter
PublicKeyHashAdapter
SecondaryKeyStore<K, V, T>
SecondaryKeyStoreManager
SecondaryPersistenceStore
SecondaryPersistenceStoreFactory
SynchronizableKeyStore<K, V, T>
WritableKeystore<K, V>
WritableKeystore represents a data store like a database that allows CRUD operations on the values belonging to the keys

Constants

client → const AtClientAnnotation
use @server to mark methods exclusively used by at_client
server → const AtServerAnnotation
use @server to mark methods exclusively used by at_secondary_server

Functions

main() → void

Exceptions / Errors

DataStoreException
An exception that provides information on a data store access or error thrown by data stores. Each DataStoreException provides the following information: A string describing the error, available via the method getMesasge. An integer error code that is specific to a data store. This is the actual error code returned by the underlying data store. And a Instance of actual exception returned by the data store.