AtAccessLogManager class abstract

Factory class. Responsible for returning instance of a AtCommitLog.

Implementers

Constructors

AtAccessLogManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAccessLog(String atSign, {String? accessLogPath}) Future<AtLogType?>
Retrieves an instance of AtCommitLog.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited