AtCompactionService class

The AtCompactionService is runs on the Keystore and removes the oldest keys to reduce the size of the Keystore.

The executeCompaction method is responsible for fetching the oldest keys and removing from the keystore

The _generateStats method collects the metrics of the compaction and returns AtCompactionStats

Constructors

AtCompactionService.getInstance()
factory

Properties

atCompactionStats AtCompactionStats
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

executeCompaction(AtLogType atLogType) Future<AtCompactionStats>
atCompactionConfig is an object containing compaction configuration/parameters atLogType specifies which logs the compaction job will run on Method chooses which type of compaction to be run based on atCompactionConfig
executeCompactionInternal(AtLogType atLogType) Future<void>
Gets the keys to delete on compaction and removes from the keystore
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited