BaseCommitLogKeyStore class abstract

Implementers

Constructors

BaseCommitLogKeyStore(String currentAtSign)

Properties

currentAtSign String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storagePath String
getter/setter pairinherited

Methods

close() Future<void>
inherited
get(int commitId) Future<CommitEntry?>
getBox() → BoxBase
inherited
getChanges(int sequenceNumber, {String? regex, int? limit}) Future<List<CommitEntry>>
Returns the list of commit entries greater than sequenceNumber throws DataStoreException if there is an exception getting the commit entries
getSize() int
inherited
getValue(dynamic key) Future<CommitEntry?>
inherited
init(String storagePath, {bool isLazy = true}) Future<void>
inherited
initialize() Future<void>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openBox(String boxName, {List<int>? hiveSecret}) Future<void>
inherited
remove(int commitEntryIndex) Future<void>
toString() String
A string representation of this object.
inherited
update(int commitId, CommitEntry? commitEntry) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited