getChanges method

Future<List<CommitEntry>> getChanges(
  1. int sequenceNumber, {
  2. String? regex,
  3. int? limit,
})

Returns the list of commit entries greater than sequenceNumber throws DataStoreException if there is an exception getting the commit entries

Implementation

Future<List<CommitEntry>> getChanges(int sequenceNumber,
    {String? regex, int? limit}) async {
  throw UnimplementedError();
}