DataStoreException class
An exception that provides information on a data store access or error thrown by data stores. Each DataStoreException provides the following information: A string describing the error, available via the method getMesasge. An integer error code that is specific to a data store. This is the actual error code returned by the underlying data store. And a Instance of actual exception returned by the data store.
- Implemented types
Constructors
- DataStoreException(String message, {int? vendorErrorCode, Exception? vendorException})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- message ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- vendorErrorCode ↔ int?
-
getter/setter pair
- vendorException ↔ Exception?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns the cause of the exception
@return String : Returns the exception cause.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited