instanceCount property
int
get
instanceCount
Instances built so far, for tests that assert the sharing rule.
Implementation
static int get instanceCount => _byPath.length;
Instances built so far, for tests that assert the sharing rule.
static int get instanceCount => _byPath.length;