CommitLogKeyStore class
- Inheritance
-
- Object
- BaseCommitLogKeyStore
- CommitLogKeyStore
- Implementers
- Annotations
Constructors
- CommitLogKeyStore(String currentAtSign)
Properties
- commitLogCache ↔ CommitLogCache
-
getter/setter pair
- currentAtSign ↔ String
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- latestCommitId → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storagePath ↔ String
-
getter/setter pairinherited
Methods
-
add(
CommitEntry? commitEntry) → Future< int> -
close(
) → Future< void> -
inherited
-
commitEntriesList(
) → List< MapEntry< String, CommitEntry> > - Not a part of API. Added for unit test
-
entriesCount(
) → int - Returns the total number of keys @return - int : Returns number of keys in access log
-
firstCommittedSequenceNumber(
) → int? - Returns the first committed sequence number
-
get(
int commitId) → Future< CommitEntry?> -
inherited
-
getBox(
) → BoxBase -
inherited
-
getChanges(
int sequenceNumber, {String? regex, int? limit}) → Future< List< CommitEntry> > -
Returns the list of commit entries greater than
sequenceNumberthrows DataStoreException if there is an exception getting the commit entriesinherited -
getDuplicateEntries(
) → Future< List< int> > -
getEntries(
int commitId, {String regex = '.*', int limit = 25, int? skipDeletesUntil}) → Iterator< MapEntry< String, CommitEntry> > -
Returns the Iterator of entries as Key value pairs after the given the
commitIdfor the keys that matches theregex -
getEntriesCount(
) → int - Returns the total number of keys in commit log keystore.
-
getExpired(
int expiryInDays) → Future< List< int> > -
getFirstNEntries(
int N) → List - Gets the first 'N' keys from the logs @param - N : The integer to get the first 'N' @return List of first 'N' keys from the log
-
getLatestCommitEntry(
String key) → CommitEntry? - Returns the latest commitEntry of the key.
-
getSize(
) → int -
inherited
-
getValue(
dynamic key) → Future< CommitEntry?> -
inherited
-
init(
String storagePath, {bool isLazy = true}) → Future< void> -
inherited
-
initialize(
) → Future< void> -
lastCommittedSequenceNumberWithRegex(
String regex, {List< String> ? enrolledNamespace}) → Future<int?> - Returns the latest committed sequence number with regex
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openBox(
String boxName, {List< int> ? hiveSecret}) → Future<void> -
inherited
-
remove(
int commitEntryIndex) → Future< void> -
override
-
removeAll(
List< int> deleteKeysList) → Future<void> -
removeEntriesWithMalformedAtKeys(
Map< int, CommitEntry> allEntries) → Future<List< String> > - Removes all entries which have a malformed CommitEntry.atKey Returns the list of CommitEntry.atKeys which were removed
-
repairCommitLogAndCreateCachedMap(
) → Future< bool> - Removes entries with malformed keys Repairs entries with null commit IDs Clears and repopulates the commitLogCache
-
repairNullCommitIDs(
Map< int, CommitEntry> commitLogMap) → Future<void> - For each commitEntry with a null commitId, replace the commitId with the hive internal key
-
toMap(
) → Future< Map< int, CommitEntry> > - Returns the key-value pair of commit-log where key is hive internal key and value is CommitEntry
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
int commitId, CommitEntry? commitEntry) → Future< void> -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited