compact method
Compact the keystore. The Hive impl delegates to its internal commit log's compaction; a client-side bundle (no commit log) is a no-op and yields nothing.
Element type is Object to allow concrete impls to yield
whatever the underlying compaction operates on (commit ids for
server-side; nothing for client-side).
Implementation
@override
Stream<Object> compact(bool dryRun) =>
_commitLog?.compact(dryRun) ?? const Stream.empty();